### APITestka
[![Downloads](https://static.pepy.tech/badge/je-api-testka)](https://pepy.tech/project/je-api-testka)

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/f243c4edfc1f4aa3ac87752e3e86b399)](https://www.codacy.com/gh/JE-Chen/APITestka/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=JE-Chen/APITestka&amp;utm_campaign=Badge_Grade)

[![APITestka Stable Python3.8](https://github.com/Intergration-Automation-Testing/APITestka/actions/workflows/stable_python3_8.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/APITestka/actions/workflows/stable_python3_8.yml)

[![APITestka Stable Python3.9](https://github.com/Intergration-Automation-Testing/APITestka/actions/workflows/stable_python3_9.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/APITestka/actions/workflows/stable_python3_9.yml)

[![APITestka Stable Python3.10](https://github.com/Intergration-Automation-Testing/APITestka/actions/workflows/stable_python3_10.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/APITestka/actions/workflows/stable_python3_10.yml)

[![APITestka Stable Python3.11](https://github.com/Intergration-Automation-Testing/APITestka/actions/workflows/stable_python3_11.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/APITestka/actions/workflows/stable_python3_11.yml)

### Documentation

[![Documentation Status](https://readthedocs.org/projects/apitestka/badge/?version=latest)](https://apitestka.readthedocs.io/en/latest/?badge=latest)

[APITestka Doc Click Here!](https://apitestka.readthedocs.io/en/latest/)

---
> Project Kanban \
> https://github.com/orgs/Integration-Automation/projects/2/views/1 \
> * API requests automation.
> * Data comparison for each Request.
> * API request in pure CLI mode.
> * Detailed reports on Requests and Responses.
> * HTTP/HTTPS support.
> * SOAP/XML support.
> * JSON support.
> * Generate JSON/HTML/XML report.
> * APITestka script.
> * 1 sec / thousands requests.
> * OS Independent.
> * Mockserver support.
> * Remote Automation support.
> * Project & Template support.
> * httpx Client(NEW)
> * httpx sync/async request.
> * http/2 request support. 


---


## install
> pip install je_api_testka


## Requires
> python 3.9 or later

### Architecture Diagram
![Architecture Diagram](architecture_diagram/APITestka_Architecture.drawio.png)